# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/).

## [Unreleased]

## [2023.6.0]

### Added
- minimum viable can actually run reactions via Bluesky

## [2023.4.0]

### Added
- initial release

[Unreleased]: https://github.com/uw-madison-chem-shops/auto_rxn/-/compare/v2023.6.0...main
[2023.6.0]: https://github.com/uw-madison-chem-shops/auto_rxn/-/compare/v2023.4.0...2023.6.0
[2023.4.0]: https://github.com/uw-madison-chem-shops/auto_rxn/-/tags/v2023.4.0

